import lejos.robotics.*;
import lejos.robotics.navigation.*;
import lejos.nxt.*;

/**
 * Class BaseRobot contains methods that can be used by another program to control the 
 * BaseRobot so it drives around the Komodo Island.  
 */
class BaseRobot
{
    double wheelDiameter  = 5.6;  // cm
    double trackWidth     = 11.3; // cm
    int travelSpeed       = 20;   // cm/sec
    int rotateSpeed       = 90;   // degree/sec
    // Two motors drive the robot. The left motor is connected to port C, the right motor
    // to port B. The motors have been build into the base so that the base robot
    // would go backwards when ordered to go forward. Therefore, the direction of the two motors
    // have been inverted so the robot goes forward when commanded to, e.g. in the steer command.
    RegulatedMotor leftMotor  = MirrorMotor.invertMotor(Motor.C),
                   rightMotor = MirrorMotor.invertMotor(Motor.B);
    DifferentialPilot robot = new DifferentialPilot( wheelDiameter, trackWidth, leftMotor, rightMotor);
    
    // Lightsensor connected to port 1 points to the left at the front of the robot
    LightSensor lightWall = new LightSensor(SensorPort.S1);
    int white;
    int corner;
    
    /**
     * Constructor that creates an instance of the BaseRobot with
     * threshold values for the white wall and the corner of the wall.
     */
    public BaseRobot(int white, int corner)
    {        
        this.white  = white;
        this.corner = corner;
        robot.setTravelSpeed(travelSpeed); 
        robot.setRotateSpeed(rotateSpeed);
    }
    
      /**
     * Method that make the robot stop.
     */
    public void stop()
    {  
        robot.stop();
    }
    
     /**
     * Method that make the robot drive forward a little to the left. Then the method waits
     * until the robot is close to the white wall.
     */
    public void forwardTowardsWall()
    {  
        robot.steer(10); // go forward a little to the left
        while ( lightWall.readValue() < white );
    }
    
     /**
     * Method that make the robot drive forward a little to the left. Then the method waits
     * until the robot is at a corner of the island, i.e. at the end of a white wall.
     */
    public void forwardUntilCorner()
    {  
        robot.steer(10); // go forward a little to the left
        while ( lightWall.readValue() > corner );
    }
    
     /**
     * Method that make the robot turn counterclockwise around a corner of the island. 
     */
    public void aroundCorner()
    {  
        robot.travel(17);   // drive forward 17 cm
        // rotate left until tha robot is close to the white wall
        robot.rotateLeft();
        while ( lightWall.readValue() < white );
    }
    
}